@@ -1,8 +1,8 @@
 from distillation.semiSupervised import *
 
-__all__=['pureDistillation','dataDistillation','modelDistillation','modelDataDistillation']
+__all__=['plainDistillation','dataDistillation','modelDistillation','modelDataDistillation']
 
-pureDistillation.__module__='distillation'
+plainDistillation.__module__='distillation'
 dataDistillation.__module__='distillation'
 modelDistillation.__module__='distillation'
-modelDataDistillation.__module__='distillation'
\ No newline at end of file
+modelDataDistillation.__module__='distillation'
