@@ -23,7 +23,7 @@ def plainDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath,
         # Create base learner
         save = SaveModelCallback(monitor='accuracy', fname='model-'+baseModel)
         early = EarlyStoppingCallback(monitor='accuracy', patience=8)
-        learn = Learner(dls, bModel, splitter=default_split, metrics=[accuracy], cbs=[early, save])
+        learn = Learner(dls, bModel, metrics=[accuracy], cbs=[early, save])
 
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
@@ -44,7 +44,7 @@ def plainDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath,
         # Create base learner
         save2 = SaveModelCallback(monitor='accuracy', fname='model-' + targetModel)
         early2 = EarlyStoppingCallback(monitor='accuracy', patience=8)
-        learn2 = Learner(dls2, tModel, splitter=default_split, metrics=[accuracy], cbs=[early2, save2])
+        learn2 = Learner(dls2, tModel, metrics=[accuracy], cbs=[early2, save2])
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
