@@ -14,6 +14,7 @@ import os
 from efficientnet_pytorch import EfficientNet
 import importlib
 import timm
+from tqdm import tqdm
 
 
 availableModels=['ResNet18','ResNet50','ResNet101','EfficientNet','FBNet','MixNet','MNasNet','MobileNet','SqueezeNet','ShuffleNet']
@@ -143,11 +144,11 @@ def plainSupervised(path,pathUnlabelled,learn,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
-    for image in images:
+    for image in tqdm(images):
         pn=learn.predict(image)
         if pn[2][pn[2].argmax()]>th:
             shutil.copyfile(image,newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
-            print(image+" --> "+newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
+            # print(image+" --> "+newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
 
 
 
